---
author:
- 'Peter E. Levy'
- 'Sarah R. Leeson'
- Netty van Dijk
- Julia Drewer
- Sophie Robinson
- 'Matthew R. Jones'
- John Kentisbeer
- Ian Washbourne
- 'Mark A. Sutton'
- 'Lucy J. Sheppard'
title: |
    Nitrous oxide emissions from a peatbog after thirteen years of
    experimental nitrogen deposition - Materials and methods
---

Field site
==========

Whim bog in the Scottish Borders (3 deg 16’ W, 55 deg 46’ N) represents a
transition between a lowland raised bog and blanket bog, on 3-6m of deep
peat. Mean temperatures of the air and soil (at 10-cm depth) were 8.6 C
and 7.7 C respectively (2003-2009 means). The annual rainfall was 1092
mm (734-1462 mm range). On average, the water table was 10 cm below the
surface of the peat in the hollows, i.e. relatively wet for most of the
year. Hummocks were typically 20 cm higher than the hollows. The peat
was very acidic, with pH 3.4 (3.27-3.91 in water). The vegetation was
classified as a *Calluna vulgaris- Eriophorum vaginatum* blanket mire
community [M19 in the UK National Vegetation Classification,
@Rodwell1998]. Replicate plots were highly variable and dominated by
unmanaged *Calluna* of variable age and stature occurring as mosaics
containing *Calluna vulgaris* and *Sphagnum capillifolium* hummocks and
hollows containing *S. fallax* and *S. papillosum*. Other common species
included *Erica tetralix* and the mosses *Hypnum jutlandicum* and
*Pleurozium schreberi*.

Experimental Design and Treatments
==================================

Nitrogen was applied to the site using two different treatment systems,
for dry deposition of NH$_3$ gas, and wet deposition of NH$_4^+$ and
NO$_3^-$ in solution. Treatments commenced in June 2002 and continued
all year round, except when temperatures were near freezing.

NH$_3$ deposition was manipulated using a free-air release system
[@Leith2004]. NH$_3$ was supplied from a cylinder of pure liquid NH$_3$,
diluted with ambient air and released from a perforated 10-m long pipe,
1 m off the ground. NH$_3$ was released only when the wind direction was
in the south-west, between 180 and 215, temperatures exceeded freezing
and wind speed exceeded 2.5 m s$^{-1}$. This produced a sector downwind
wherein NH$_3$ decreased with distance from the fumigation source.
NH$_3$ concentrations were measured 0.1 m above the vegetation using
passive ALPHA samplers [@Tang2001] at 8, 12, 16, 20, 24, 32, 48 and 60 m
from the source along the transect. A detailed profile was measured to
capture the concentration gradients both vertically and horizontally
[@Leith2004]. Ammonia deposition was calculated from the concentration
measurements, using the method of [@Cape2008]. The deposition at these
locations was interpolated using ordinary kriging, assuming the
deposition velocity was spatially homogeneous.

Wet deposition of NH$_4^+$ and NO$_3^-$ was experimentally increased in
a number of replicated plots in a randomised block design, using a water
sprayer system [@Sheppard2004]. Concentrated solutions of either
NH$_4$Cl or NaNO$_3$ were diluted in rainwater, and transferred to each
plot via 100-m lengths of 16-mm pipe. Each pipe terminated in a central
sprayer with a 360spinning disc that distributed the solution uniformly
over the 12.8 m$^2$ plot. The volume of soulution applied to each plot
was monitored using a water meter on each supply line. Three treatment
levels were applied, aiming to provide total N deposition rates of 16,
32 and 64 kg N ha$^{-1}$ y$^{-1}$, in addition to a control treatment
which only received ambient N deposition (8 kg N ha$^{-1}$ y$^{-1}$).
The three treatment levels were achieved by applying either NH$_4$Cl or
NaNO$_3$ solution at concentrations of 0.57, 1.71 or 4.0 mM. Wet
treatments increased precipitation amounts by ca. 10%. Control plots
receive the additional rainwater without any additional nitrogen. There
were four blocks, with one treatment level in each, to give a total of
28 plots. The sprayer system was automatically triggered every 15
minutes, so long as there was sufficient rainwater in the collection
tank, air temperature was above 0 C and wind speed was above 5 m
s$^{-1}$. This produced a realistic pattern of high frequency, extensive
nitrogn deposition, with ca. 120 applications y$^{-1}$.

Collection methods - Soil Water Chemistry
=========================================

Soil water samples were extracted from dipwells in all plots at the same
time as gas flux measurements were made. Concentrations of soil water
NH$_4^+$ and NO$_3^-$ were measured by ion chromatography following
filtration. The detection limits were 0.014 and 0.062 mg l$^{-1}$ for
NH$_4^+$-N and NO$_3^-$-N respectively. The percent cover of each
vegetation species was recorded within each chamber location every few
years.

Collection methods - Greenhouse gas exchange
============================================

Nitrous oxide fluxes were measured by the static chamber method
[@Hutchinson1981], typically on a monthly basis. Cylindrical PVC collars
(38 cm in diameter and typically 25 cm high) were inserted into the peat
within each plot. On each sampling occasion, a lid was sealed on top,
and left in place for 30-40 minutes. Four 20-ml samples were removed by
syringe through a 3-way tap or rubber septum, stored in vials or tedlar
bags.

Laboratory Instrumentation
==========================

Gas samples were analysed on a gas chromatograph (5890 series II,
Hewlett Packard), together with replicates of three or four standard
gases with known concentrations.

Calibration steps and values
============================

Samples run on the gas chromatograph were converted to mole fractions
using a 4 point calibration, see Table  \[tab:GCcalib\] for standard
mole fractions, with standards run approximately every 20 samples.

    Standard no.   N$_2$O ($\mu$ mol mol$^{-1}$)       
  -------------- ------------------------------- -- -- --
               1                           0.199       
               2                           0.285       
               3                           0.490       
               4                           0.975       

  : Nitrous oxide mole fractions of standards used in calibrating gas
  samples from chambers on the gas
  chromatograph.[]{data-label="tab:GCcalib"}

Analytical methods and Quality Control
======================================

For each sequence of gas samples from a chamber, the flux was calculated
as:

$$F = \frac{\mathrm{d}C}{\mathrm{d}t_{0}} \cdot \frac{\rho V}{A}$$

Where $F$ is gas flux from the soil (${\mu}$molm$^{-2}$s$^{-1}$),
$\mathrm{d}C/\mathrm{d}t_0$ is the initial rate of change in
concentration with time in ${\mu}$molmol$^{-1}$s$^{-1}$, $\rho$ is the
density of air in , $V$ is the volume of the chamber in and $A$ is the
ground area enclosed by the chamber in .

The parameter $\mathrm{d}C/\mathrm{d}t_0$ was calculated using linear
and non-linear asymptotic regression methods [@Levy2011]. Using a
mixture of goodness-of-fit statistics and visual inspection, the
regression method that provided the best fit for the time series of
concentration was chosen for each individual measurement. With this
method of flux calculation, any non-linearity should be accounted for as
far as possible. However, the time resolution (approximately 10 minutes)
limits the detectable degree of non-linearity in the initial
concentration change, so there remains some potential for
underestimation of fluxes [@Cowan2014].

Statistical analysis
====================

The data were first analysed using a linear mixed-effects model
[@Pinheiro2006]. There were 729 flux measurements in total, after
removing four outlying measurements above 10 nmol m$^{-2}$s$^{-1}$ and
two below -2 nmol m$^{-2}$s$^{-1}$. We fitted fixed-effect terms for
soil temperature, $T_\mathrm{soil}$, water table height,
$z_\mathrm{water}$ (negative values indicate depth below the surface),
ammonia-N deposition rate, $F_\mathrm{N-NH_3}$, ammonium-N deposition
rate, $F_\mathrm{N-NH_4}$, and nitrate-N deposition rate,
$F_\mathrm{N-NO_3}$, and random-effect terms with a design matrix
$\mathrm{Z_{i,j}}$ to account for the repeated measures on each chamber
location, *j*, nested within each experimental block, *i* :

$$F_\mathrm{N_{2}O,ij} = \beta_{0} + \beta_{1}\cdot T_\mathrm{soil,ij} + \beta_{2}\cdot z_\mathrm{water,ij}
   + \beta_{3}\cdot F_\mathrm{NH_3,ij} + \beta_{4}\cdot F_\mathrm{NH_4,ij} + \beta_{5}\cdot F_\mathrm{NO_3,ij}
   + b_{i}\cdot \mathrm{Z_{i,j}} + b_{ij}\cdot \mathrm{Z_{ij}} + \epsilon_{ij}$$

$b_{i} \sim N(0,\sigma^2_1)$ $b_{ij} \sim N(0,\sigma^2_2)$
$\epsilon_{ij} \sim N(0,\sigma^2_3)$.\

Nature and Units of recorded values
===================================

The following tables list the variables in each of the files in the data
set.

       Variable name                     Units                                                                    Description    
  ------------------ ------------------------- ------------------------------------------------------------------------------ -- --
           ChamberID                        na                                               Unique ID for each chamber, 1-72    
         chamberCode                        na                                Code consisting of PlotNumber and SubPlotNumber    
      chamberID-4dig                        na                                                        Four-digit chamber code    
    ExperimentalGrid                        na                                                       “Wet”, “Dry”, or “Ozone”    
                form                        na                                          Form of N deposition - “Wet” or “Dry”    
             BlockID                        na      ID for each experimental block - see Figure \[fig:Whim\_treatment\_plan\]    
          PlotNumber                        na       ID for each experimental plot - see Figure \[fig:Whim\_treatment\_plan\]    
       SubPlotNumber                        na   ID for each experimental sub-plot - see Figure \[fig:Whim\_treatment\_plan\]    
                 lon                   degrees                                                      Longitude of each chamber    
                 lat                   degrees                                                      Longitude of each chamber    
                Fnh3   kg N ha$^{-1}$ y$^{-1}$                                                 Flux of NH$_3$ to each chamber    
                Fnh4   kg N ha$^{-1}$ y$^{-1}$                                                 Flux of NH$_4$ to each chamber    
                Fno3   kg N ha$^{-1}$ y$^{-1}$                                                 Flux of NO$_3$ to each chamber    
          Ndep-total   kg N ha$^{-1}$ y$^{-1}$                                                Total flux of N to each chamber    

  : `ancilliaryData-byChamber.csv`. The file contains ancilliary data
  for each chamber. The four-digit chamber code is formatted EPPS, where
  E is the experiment, PP is the two-digit PlotNumber and S is the
  SubPlotNumber[]{data-label="tab:ancilliaryData_Whim_byChamber"}

        Variable name                     Units                                                 Description    
  ------------------- ------------------------- ----------------------------------------------------------- -- --
    chamberCodeinFile                        na                   Code used for chamber in GC raw data file    
              gasName                        na                                                  “N2O” only    
             filename                        na                                   File name for raw GC data    
         fullpathname                        na                    File name for raw GC data including path    
                 date                dd/mm/YYYY                                         Date of measurement    
      chamberID\_4dig                        na           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                  lon                   degrees           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                  lat                   degrees   see Table \[tab:ancilliaryData\_Whim\_byChamber\_byDate\]    
              BlockID   kg N ha$^{-1}$ y$^{-1}$           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
               PlotID   kg N ha$^{-1}$ y$^{-1}$           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                 form   kg N ha$^{-1}$ y$^{-1}$           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                 Fnh3   kg N ha$^{-1}$ y$^{-1}$           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                 Fnh4   kg N ha$^{-1}$ y$^{-1}$           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                 Fno3   kg N ha$^{-1}$ y$^{-1}$           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
           Ndep-total   kg N ha$^{-1}$ y$^{-1}$           see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
            Tair-degC                 degrees C                                  Air temperature in chamber    
           Tsoil-degC                 degrees C                                 Soil temperature in chamber    
           WTdepth-cm                        cm                         Water table depth below the surface    

  : `ancilliaryData-byChamber-byDate.csv`. The file contains ancilliary
  data which vary by chamber and by
  date.[]{data-label="tab:ancilliaryData_Whim_byChamber_byDate"}

        Variable name                           Units                                                     Description    
  ------------------- ------------------------------- --------------------------------------------------------------- -- --
             filename                              na                                       File name for raw GC data    
         fullpathname                              na                        File name for raw GC data including path    
          flux linear   nmol N$_2$O m$^{-2}$ s$^{-1}$                                 Flux calculated by linear model    
       flux quadratic   nmol N$_2$O m$^{-2}$ s$^{-1}$                              Flux calculated by quadratic model    
       flux linear2nd   nmol N$_2$O m$^{-2}$ s$^{-1}$                                 Flux calculated by linear model    
    flux quadratic2nd   nmol N$_2$O m$^{-2}$ s$^{-1}$                                 Flux calculated by linear model    
      flux asymptotic   nmol N$_2$O m$^{-2}$ s$^{-1}$                             Flux calculated by asymptotic model    
             flux HMR   nmol N$_2$O m$^{-2}$ s$^{-1}$                                    Flux calculated by HMR model    
         flux bestfit   nmol N$_2$O m$^{-2}$ s$^{-1}$                           Flux calculated by best-fitting model    
        ci95lo linear   nmol N$_2$O m$^{-2}$ s$^{-1}$         Lower 95 % confidence interval on linear model estimate    
        ci95hi linear   nmol N$_2$O m$^{-2}$ s$^{-1}$         Upper 95 % confidence interval on linear model estimate    
       ci95lo bestfit   nmol N$_2$O m$^{-2}$ s$^{-1}$   Lower 95 % confidence interval on best-fitting model estimate    
       ci95hi bestfit   nmol N$_2$O m$^{-2}$ s$^{-1}$   Upper 95 % confidence interval on best-fitting model estimate    
         adjr2 linear   nmol N$_2$O m$^{-2}$ s$^{-1}$                           Adjusted r2 for linear model estimate    
      adjr2 quadratic   nmol N$_2$O m$^{-2}$ s$^{-1}$                        Adjusted r2 for quadratic model estimate    
        bestFitMethod   nmol N$_2$O m$^{-2}$ s$^{-1}$                 Integer code for method that gives the best-fit    
    chamberCodeinFile                              na       see Table \[tab:ancilliaryData\_Whim\_byChamber\_byDate\]    

  : `RCfluxOutput.csv`. The file contains fluxes of N2O calculated by
  the RCflux program.[]{data-label="tab:RCfluxOutput"}

                Variable name           Units                                                   Description    
  --------------------------- --------------- ------------------------------------------------------------- -- --
              chamberID\_4dig              na             see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                      BlockID              na             see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                       PlotID              na             see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                         form              na             see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
             Calluna vulgaris   Percent cover   Percentage of area in chamber covered by *Calluna vulgaris*    
    $\hdots$ for each species   Percent cover         Percentage of area in chamber covered by each species    

  : `vegetation-speciesPercentCover-Whim-byChamber.csv`. The file
  contains percent cover data for each species in each
  chamber.[]{data-label="tab:vegetation_speciesPercentCover_Whim_byChamber"}

              Variable name            Units                                           Description    
  ------------------------- ---------------- ----------------------------------------------------- -- --
            chamberID\_4dig               na     see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                    BlockID               na     see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                     PlotID               na     see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                       form               na     see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                  Jun\_2010   mg N per litre     Ammonium concentration in soil water in June 2010    
    $\hdots$ for each month   mg N per litre   Ammonium concentration in soil water for each month    

  : `chemistry-NH4mgNperl-Whim-byChamber-byDate.csv`. The file contains
  soil water ammonium concentrations for each chamber and
  date.[]{data-label="tab:chemistry_NH4mgNperl_Whim_byChamber_byDate"}

              Variable name            Units                                          Description    
  ------------------------- ---------------- ---------------------------------------------------- -- --
            chamberID\_4dig               na    see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                    BlockID               na    see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                     PlotID               na    see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                       form               na    see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                  Jun\_2010   mg N per litre     Nitrate concentration in soil water in June 2010    
    $\hdots$ for each month   mg N per litre   Nitrate concentration in soil water for each month    

  : `chemistry-NO3mgNperl-Whim-byChamber-byDate.csv`. The file contains
  soil water nitrate concentrations for each chamber and
  date.[]{data-label="tab:chemistry_NO3mgNperl_Whim_byChamber_byDate"}

              Variable name   Units                                         Description    
  ------------------------- ------- --------------------------------------------------- -- --
            chamberID\_4dig      na   see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                    BlockID      na   see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                     PlotID      na   see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                       form      na   see Table \[tab:ancilliaryData\_Whim\_byChamber\]    
                  Jun\_2010      pH                       pH in soil water in June 2010    
    $\hdots$ for each month      pH                     pH in soil water for each month    

  : `chemistry-pH-Whim-byChamber-byDate.csv`. The file contains soil
  water pH concentrations for each chamber and
  date.[]{data-label="tab:chemistry_pH_Whim_byChamber_byDate"}

![Layout of N deposition plots in the Whim
experiment.[]{data-label="fig:Whim_treatment_plan"}](Whim_treatment_plan.png){width="12cm"}


REFERENCES 
Cape, J., Jones, M., Leith, I., Sheppard, L., van Dijk, N., Sutton, M., and Fowler, D. (2008). Estimate of annual NH3 dry deposition to a fumigated ombrotrophic bog using concentration-dependent deposition velocities. At- mospheric Environment, 42(27):6637-6646. 

Cowan, N. J., Famulari, D., Levy, P. E., Anderson, M., Reay, D. S., and Skiba, U. M. (2014). Investigating uptake of N2O in agricultural soils using a high- precision dynamic chamber method. Atmospheric Measurement Techniques, 7(12):4455-4462. 

Hutchinson, G. L. and Mosier, A. R. (1981). Improved Soil Cover Method for Field Measurement of Nitrous Oxide Fluxes1. Soil Science Society of America Journal, 45(2):311. 

Leith, I. D., Sheppard, L. J., Fowler, D., Cape, J. N., Jones, M., Crossley, A., Hargreaves, K. J., Tang, Y. S., Theobald, M., and Sutton, M. R. (2004). Quantifying Dry NH3 Deposition to an Ombrotrophic Bog from an Auto- mated NH3 Field Release System. Water, Air, & Soil Pollution: Focus, 4(6):207-218. 

Levy, P. E., Gray, A., Leeson, S. R., Gaiawyn, J., Kelly, M. P. C., Cooper, M. D. A., Dinsmore, K. J., Jones, S. K., and Sheppard, L. J. (2011). Quan- tiffcation of uncertainty in trace gas uxes measured by the static chamber method. European Journal of Soil Science, 62(6):811-821. 

Pinheiro, J. and Bates, D. (2006). Mixed-Effects Models in S and S-PLUS. Springer Science & Business Media. 

Rodwell, J. S. (1998). British Plant Communities. Cambridge University Press. 

Sheppard, L. J., Crossley, A., Leith, I. D., Hargreaves, K. J., Carfrae, J. A., van Dijk, N., Cape, J. N., Sleep, D., Fowler, D., and Raven, J. A. (2004). An Automated Wet Deposition System to Compare the Effects of Reduced and Oxidised N on Ombrotrophic Bog Species: Practical Considerations. Water, Air, & Soil Pollution: Focus, 4(6):197-205. 

Tang, Y. S., Cape, J. N., and Sutton, M. A. (2001). Development and Types of Passive Samplers for Monitoring Atmospheric NO2 and NH3 Concentrations. The Scientiffc World Journal, 1:513-529.